@@ -72,7 +72,29 @@ class DatabaseAccessRule(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DatabaseAccessRule.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                description: builtins.str,
+                name: builtins.str,
+                ports: builtins.str,
+                service_instance_id: builtins.str,
+                source: builtins.str,
+                destination: typing.Optional[builtins.str] = None,
+                enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                timeouts: typing.Optional[typing.Union[DatabaseAccessRuleTimeouts, typing.Dict[str, typing.Any]]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DatabaseAccessRuleConfig(
@@ -198,7 +220,9 @@ class DatabaseAccessRule(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -210,7 +234,9 @@ class DatabaseAccessRule(
     @destination.setter
     def destination(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "destination").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "destination", value)
 
@@ -222,7 +248,9 @@ class DatabaseAccessRule(
     @enabled.setter
     def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "enabled").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enabled", value)
 
@@ -234,7 +262,9 @@ class DatabaseAccessRule(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -246,7 +276,9 @@ class DatabaseAccessRule(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -258,7 +290,9 @@ class DatabaseAccessRule(
     @ports.setter
     def ports(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "ports").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ports", value)
 
@@ -270,7 +304,9 @@ class DatabaseAccessRule(
     @service_instance_id.setter
     def service_instance_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "service_instance_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "serviceInstanceId", value)
 
@@ -282,7 +318,9 @@ class DatabaseAccessRule(
     @source.setter
     def source(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRule, "source").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "source", value)
 
@@ -353,7 +391,27 @@ class DatabaseAccessRuleConfig(cdktf.TerraformMetaArguments):
         if isinstance(timeouts, dict):
             timeouts = DatabaseAccessRuleTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(DatabaseAccessRuleConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                description: builtins.str,
+                name: builtins.str,
+                ports: builtins.str,
+                service_instance_id: builtins.str,
+                source: builtins.str,
+                destination: typing.Optional[builtins.str] = None,
+                enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                timeouts: typing.Optional[typing.Union[DatabaseAccessRuleTimeouts, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -557,7 +615,13 @@ class DatabaseAccessRuleTimeouts:
         :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas/r/database_access_rule#delete DatabaseAccessRule#delete}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DatabaseAccessRuleTimeouts.__init__)
+            def stub(
+                *,
+                create: typing.Optional[builtins.str] = None,
+                delete: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -605,7 +669,12 @@ class DatabaseAccessRuleTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DatabaseAccessRuleTimeoutsOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -636,7 +705,9 @@ class DatabaseAccessRuleTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRuleTimeoutsOutputReference, "create").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -648,7 +719,9 @@ class DatabaseAccessRuleTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRuleTimeoutsOutputReference, "delete").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -665,7 +738,11 @@ class DatabaseAccessRuleTimeoutsOutputReference(
         value: typing.Optional[typing.Union[DatabaseAccessRuleTimeouts, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DatabaseAccessRuleTimeoutsOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[DatabaseAccessRuleTimeouts, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
