@@ -60,7 +60,23 @@ class OraclepaasProvider(
         :param mysql_endpoint: The HTTP endpoint for Oracle MySQL operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas#mysql_endpoint OraclepaasProvider#mysql_endpoint}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(OraclepaasProvider.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                identity_domain: builtins.str,
+                password: builtins.str,
+                user: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                application_endpoint: typing.Optional[builtins.str] = None,
+                database_endpoint: typing.Optional[builtins.str] = None,
+                insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                java_endpoint: typing.Optional[builtins.str] = None,
+                max_retries: typing.Optional[jsii.Number] = None,
+                mysql_endpoint: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = OraclepaasProviderConfig(
@@ -175,7 +191,9 @@ class OraclepaasProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "alias").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -187,7 +205,9 @@ class OraclepaasProvider(
     @application_endpoint.setter
     def application_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "application_endpoint").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "applicationEndpoint", value)
 
@@ -199,7 +219,9 @@ class OraclepaasProvider(
     @database_endpoint.setter
     def database_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "database_endpoint").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "databaseEndpoint", value)
 
@@ -211,7 +233,9 @@ class OraclepaasProvider(
     @identity_domain.setter
     def identity_domain(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "identity_domain").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "identityDomain", value)
 
@@ -228,7 +252,11 @@ class OraclepaasProvider(
         value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "insecure").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "insecure", value)
 
@@ -240,7 +268,9 @@ class OraclepaasProvider(
     @java_endpoint.setter
     def java_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "java_endpoint").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "javaEndpoint", value)
 
@@ -252,7 +282,9 @@ class OraclepaasProvider(
     @max_retries.setter
     def max_retries(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "max_retries").fset)
+            def stub(value: typing.Optional[jsii.Number]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "maxRetries", value)
 
@@ -264,7 +296,9 @@ class OraclepaasProvider(
     @mysql_endpoint.setter
     def mysql_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "mysql_endpoint").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mysqlEndpoint", value)
 
@@ -276,7 +310,9 @@ class OraclepaasProvider(
     @password.setter
     def password(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "password").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -288,7 +324,9 @@ class OraclepaasProvider(
     @user.setter
     def user(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(OraclepaasProvider, "user").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "user", value)
 
@@ -337,7 +375,21 @@ class OraclepaasProviderConfig:
         :param mysql_endpoint: The HTTP endpoint for Oracle MySQL operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas#mysql_endpoint OraclepaasProvider#mysql_endpoint}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(OraclepaasProviderConfig.__init__)
+            def stub(
+                *,
+                identity_domain: builtins.str,
+                password: builtins.str,
+                user: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                application_endpoint: typing.Optional[builtins.str] = None,
+                database_endpoint: typing.Optional[builtins.str] = None,
+                insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                java_endpoint: typing.Optional[builtins.str] = None,
+                max_retries: typing.Optional[jsii.Number] = None,
+                mysql_endpoint: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument identity_domain", value=identity_domain, expected_type=type_hints["identity_domain"])
             check_type(argname="argument password", value=password, expected_type=type_hints["password"])
             check_type(argname="argument user", value=user, expected_type=type_hints["user"])
